package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"D```````!``````````%#!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````,`9````````P!D`````````
M$`````````$````%`````"``````````(``````````@````````G4(`````
M``"=0@`````````0`````````0````0`````<`````````!P`````````'``
M``````#P10```````/!%`````````!`````````!````!@```,"[````````
MP,L```````#`RP```````&`$````````H!0`````````$`````````(````&
M````T+L```````#0RP```````-#+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``"0K@```````)"N````````D*X```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P+L```````#`RP```````,#+````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`5&P-^:H>JXW^ZF19
M<T6#Q]BMI`8$````$`````$```!'3E4```````,````"```````````````1
M````1`````0````(````(!`0``5`!(0H`@`$@(8`A(()```)(`0(B(`10;H`
M`@@`````1````$<```!*````2P```%(```!3````5`````````!6````5P``
M`%@```!9````6P```%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@:PE#UF>OS&9"
M1=7LB0=PTS-BV^T5C"7,#3J7"WZIG)O19<YMX*<""FL:GE"CX/M)````````
M`````````````````````````````"("```2````````````````````````
M`+@"```2`````````````````````````.@````1````````````````````
M`````)H!```2`````````````````````````*("```2````````````````
M`````````(P````1``````````````````````````D"```2````````````
M`````````````#P!```2`````````````````````````(`"```2````````
M`````````````````,4!```2``````````````````````````$````@````
M`````````````````````%T"```2`````````````````````````&<````2
M`````````````````````````)T"```2`````````````````````````)0`
M```2``````````````````````````("```2````````````````````````
M`%0"```2`````````````````````````*@"```2````````````````````
M`````-(````2`````````````````````````.(````2````````````````
M`````````%(!```2`````````````````````````'`!```2````````````
M`````````````(H````1`````````````````````````'\#```2````````
M`````````````````!`````@`````````````````````````#H"```2````
M`````````````````````"<"```2`````````````````````````+T````2
M`````````````````````````"P````@`````````````````````````)T`
M```2`````````````````````````*L````2````````````````````````
M`"P"```2``````````````````````````<!```2````````````````````
M`````-@!```2`````````````````````````"(!```2````````````````
M`````````$4"```2`````````````````````````(X"```2````````````
M`````````````*\!```2`````````````````````````$,!```2````````
M`````````````````#,!```2`````````````````````````&`!```2````
M`````````````````````'X!```2`````````````````````````!0"```2
M`````````````````````````&@"```2`````````````````````````),!
M```2`````````````````````````-D"```2````````````````````````
M`'D````2`````````````````````````(P!```2````````````````````
M`````(4!```2`````````````````````````)P````2````````````````
M`````````*@!```2`````````````````````````/,````2````````````
M`````````````,0"```2`````````````````````````/8!```2````````
M`````````````````)4"```2`````````````````````````-D````2````
M`````````````````````,0````2`````````````````````````'D"```1
M`````````````````````````.D!```1`````````````````````````*0`
M```2`````````````````````````&@!```2````````````````````````
M`!<!```2`````````````````````````+8!```2````````````````````
M`````%4````2`````````````````````````'<!```2````````````````
M`````````+,````2`````````````````````````&("```2````````````
M`````````````(@#```2`!``P%(````````&`0```````-T#```2`!``8%<`
M``````"2"````````&(````2`!``("<````````R`@```````/\"```2`!``
M($@````````)`````````!T#```2`!```&````````!Y`@````````,$```2
M`!``,$@````````"`@```````,,#```0`!H`(-```````````````````!`#
M```2`!``0$H````````E`````````#,#```2`!``H%````````!\````````
M`)0#```1`!(``'`````````$`````````+`#```2`!``T%,```````"?`0``
M`````+L#```2`!```$<````````W`````````-@#```0`!H`8.``````````
M`````````/$#```2`!``4%$````````+`0```````*,#```0`!D``-``````
M`````````````%<#```2`!``<$H```````#<`````````.H#```0`!D`(-``
M`````````````````!`$```1`!D`&-`````````(`````````*D#```2`!``
M8"D````````F`````````,\#```2`!``8%(```````!8`````````*4#```@
M`!D``-```````````````````&T#```2`!``(%$````````A`````````$8`
M```B`````````````````````````$$#```2`!``0$<```````#8````````
M`&,#```2`!``<%4```````#K`0```````!H$```2`!``4$L```````!&!0``
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7V-X85]F:6YA;&EZ90!?
M7VQI8F-?<W1A<G1?;6%I;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]F86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD
M:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S
M961I<@!R;61I<@!03%]T:')?:V5Y`'!T:')E861?9V5T<W!E8VEF:6,`8F]O
M=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D
M;&EN:P!M96UC:'(`4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!M96UM
M;W9E`')E86QL;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R=&]K`'-T<F-M
M<`!S=')D=7``7U]S=')N8W!Y7V-H:P!G971U:60`<W1R<W1R`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,
M7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`
M<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`97AI=`!M:V1I<@!?7V5R<FYO7VQO
M8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV-`!L<V5E:S8T`')E
M860`8VQO<V4`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`&QI8G!E<FPN<V\N-2XS,@!L:6)C
M+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A
M<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E
M;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,
M24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXR+C4`1TQ)0D-?,BXS+C0````!``$``0`"``,``P`!``,``@`!``$`
M`P`$``,``P`#``$``0`#``,``0`#``,``P`!``$``P`#``$`!0`#``$``0`!
M``$``0`#``,``0`#``,``P`!``,``P`!``8``P`#``4``P`'``$``0`#``,`
M`@`#``$``P`#``$``0`'``@``P`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``P`!``$``0`````````!``<`]0(``!``
M````````E)&6!@``"``G!```$````+21E@8```<`,@0``!`````4:6D-```&
M`#T$```0````LY&6!@``!0!'!```$````'(9:0D```0`4@0``!````!U&FD)
M```#`%X$```0````=!EI"0```@!J!````````,#+````````"`````````!`
M*@```````,C+````````"```````````*@````````C0````````"```````
M```(T````````!C0````````"`````````#@<@```````*#/````````!@``
M``,``````````````*C/````````!@````8``````````````+#/````````
M!@````H``````````````+C/````````!@````L``````````````,#/````
M````!@```!D``````````````,C/````````!@```!T``````````````-#/
M````````!@```%H``````````````-C/````````!@```"$`````````````
M`.#/````````!@```"(``````````````.C/````````!@```#H`````````
M`````/#/````````!@```#L``````````````/C/````````!@```$``````
M`````````.C-````````!P````$``````````````/#-````````!P````(`
M`````````````/C-````````!P````0```````````````#.````````!P``
M``4```````````````C.````````!P````<``````````````!#.````````
M!P````@``````````````!C.````````!P````D``````````````"#.````
M````!P````P``````````````"C.````````!P````T``````````````##.
M````````!P````X``````````````#C.````````!P````\`````````````
M`$#.````````!P```!```````````````$C.````````!P```!$`````````
M`````%#.````````!P```!(``````````````%C.````````!P```!,`````
M`````````&#.````````!P```!0``````````````&C.````````!P```!4`
M`````````````'#.````````!P```!8``````````````'C.````````!P``
M`!@``````````````(#.````````!P```!H``````````````(C.````````
M!P```!L``````````````)#.````````!P```!P``````````````)C.````
M````!P```!X``````````````*#.````````!P```!\``````````````*C.
M````````!P```"```````````````+#.````````!P```",`````````````
M`+C.````````!P```"0``````````````,#.````````!P```"4`````````
M`````,C.````````!P```"8``````````````-#.````````!P```"<`````
M`````````-C.````````!P```"@``````````````.#.````````!P```"D`
M`````````````.C.````````!P```"H``````````````/#.````````!P``
M`"L``````````````/C.````````!P```"P```````````````#/````````
M!P```"T```````````````C/````````!P```"X``````````````!#/````
M````!P```"\``````````````!C/````````!P```#```````````````"#/
M````````!P```#$``````````````"C/````````!P```#(`````````````
M`##/````````!P```#,``````````````#C/````````!P```#0`````````
M`````$#/````````!P```#4``````````````$C/````````!P```#8`````
M`````````%#/````````!P```#<``````````````%C/````````!P```#@`
M`````````````&#/````````!P```#D``````````````&C/````````!P``
M`#P``````````````'#/````````!P```#T``````````````'C/````````
M!P```#X``````````````(#/````````!P```#\``````````````(C/````
M````!P```$$``````````````)#/````````!P```$(``````````````)C/
M````````!P```$,`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:FO``!(A<!T`O_02(/$",,``````/\ULJT``/+_);.M
M```/'P#S#Q[Z:`````#RZ>'___^0\P\>^F@!````\NG1____D/,/'OIH`@``
M`/+IP?___Y#S#Q[Z:`,```#RZ;'___^0\P\>^F@$````\NFA____D/,/'OIH
M!0```/+ID?___Y#S#Q[Z:`8```#RZ8'___^0\P\>^F@'````\NEQ____D/,/
M'OIH"````/+I8?___Y#S#Q[Z:`D```#RZ5'___^0\P\>^F@*````\NE!____
MD/,/'OIH"P```/+I,?___Y#S#Q[Z:`P```#RZ2'___^0\P\>^F@-````\ND1
M____D/,/'OIH#@```/+I`?___Y#S#Q[Z:`\```#RZ?'^__^0\P\>^F@0````
M\NGA_O__D/,/'OIH$0```/+IT?[__Y#S#Q[Z:!(```#RZ<'^__^0\P\>^F@3
M````\NFQ_O__D/,/'OIH%````/+IH?[__Y#S#Q[Z:!4```#RZ9'^__^0\P\>
M^F@6````\NF!_O__D/,/'OIH%P```/+I<?[__Y#S#Q[Z:!@```#RZ6'^__^0
M\P\>^F@9````\NE1_O__D/,/'OIH&@```/+I0?[__Y#S#Q[Z:!L```#RZ3'^
M__^0\P\>^F@<````\NDA_O__D/,/'OIH'0```/+I$?[__Y#S#Q[Z:!X```#R
MZ0'^__^0\P\>^F@?````\NGQ_?__D/,/'OIH(````/+IX?W__Y#S#Q[Z:"$`
M``#RZ=']__^0\P\>^F@B````\NG!_?__D/,/'OIH(P```/+IL?W__Y#S#Q[Z
M:"0```#RZ:']__^0\P\>^F@E````\NF1_?__D/,/'OIH)@```/+I@?W__Y#S
M#Q[Z:"<```#RZ7']__^0\P\>^F@H````\NEA_?__D/,/'OIH*0```/+I4?W_
M_Y#S#Q[Z:"H```#RZ4']__^0\P\>^F@K````\NDQ_?__D/,/'OIH+````/+I
M(?W__Y#S#Q[Z:"T```#RZ1']__^0\P\>^F@N````\ND!_?__D/,/'OIH+P``
M`/+I\?S__Y#S#Q[Z:#````#RZ>'\__^0\P\>^F@Q````\NG1_/__D/,/'OIH
M,@```/+IP?S__Y#S#Q[Z:#,```#RZ;'\__^0\P\>^F@T````\NFA_/__D/,/
M'OIH-0```/+ID?S__Y#S#Q[Z:#8```#RZ8'\__^0\P\>^O+_)26L```/'T0`
M`/,/'OKR_R4MJ@``#Q]$``#S#Q[Z\O\E):H```\?1```\P\>^O+_)1VJ```/
M'T0``/,/'OKR_R45J@``#Q]$``#S#Q[Z\O\E#:H```\?1```\P\>^O+_)06J
M```/'T0``/,/'OKR_R7]J0``#Q]$``#S#Q[Z\O\E]:D```\?1```\P\>^O+_
M)>VI```/'T0``/,/'OKR_R7EJ0``#Q]$``#S#Q[Z\O\EW:D```\?1```\P\>
M^O+_)=6I```/'T0``/,/'OKR_R7-J0``#Q]$``#S#Q[Z\O\EQ:D```\?1```
M\P\>^O+_);VI```/'T0``/,/'OKR_R6UJ0``#Q]$``#S#Q[Z\O\EK:D```\?
M1```\P\>^O+_):6I```/'T0``/,/'OKR_R6=J0``#Q]$``#S#Q[Z\O\EE:D`
M``\?1```\P\>^O+_)8VI```/'T0``/,/'OKR_R6%J0``#Q]$``#S#Q[Z\O\E
M?:D```\?1```\P\>^O+_)76I```/'T0``/,/'OKR_R5MJ0``#Q]$``#S#Q[Z
M\O\E9:D```\?1```\P\>^O+_)5VI```/'T0``/,/'OKR_R55J0``#Q]$``#S
M#Q[Z\O\E3:D```\?1```\P\>^O+_)46I```/'T0``/,/'OKR_R4]J0``#Q]$
M``#S#Q[Z\O\E-:D```\?1```\P\>^O+_)2VI```/'T0``/,/'OKR_R4EJ0``
M#Q]$``#S#Q[Z\O\E':D```\?1```\P\>^O+_)16I```/'T0``/,/'OKR_R4-
MJ0``#Q]$``#S#Q[Z\O\E!:D```\?1```\P\>^O+_)?VH```/'T0``/,/'OKR
M_R7UJ```#Q]$``#S#Q[Z\O\E[:@```\?1```\P\>^O+_)>6H```/'T0``/,/
M'OKR_R7=J```#Q]$``#S#Q[Z\O\EU:@```\?1```\P\>^O+_)<VH```/'T0`
M`/,/'OKR_R7%J```#Q]$``#S#Q[Z\O\EO:@```\?1```\P\>^O+_);6H```/
M'T0``/,/'OKR_R6MJ```#Q]$``#S#Q[Z\O\EI:@```\?1```\P\>^O+_)9VH
M```/'T0``/,/'OKR_R65J```#Q]$``#S#Q[Z\O\EC:@```\?1```\P\>^O+_
M)86H```/'T0``/,/'OKR_R5]J```#Q]$``#S#Q[Z05152(/L.(E\)!Q(C7PD
M'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP.B#____2(LU
M3*@``$B+/76H``!(B?+H#3L``$B+!7:H``"`.``/A#,!``!,BR46J```08L\
M).B]_O__08L\)("(.@0```+HK?[__X"(.@0```&+1"0<C7@$1(U@`TAC_TC!
MYP/HK_[__TB+3"00BW0D'$F)P4B)!82H``!(BP%)B0%(C05=20``28E!"$B-
M!2RH``!(BP!)B4$02(T%1TD``$F)01B#_@$/CC(!``!(@\$(@\8#N`0````/
M'T0``$B+.4ACT(/``4B#P0A)B3S1.<9UZTAC]DB+/1&H``!$B>)%,<!)QP3Q
M`````$R)R4B--0$;``#HG/O__T&)Q(7`#X2,````2(L]XJ<``$B-;"0DZ%#]
M__\QP$B)[DB-/2=(``#H_Q<``$B%P'1Y2(L]NZ<``.@>^___Z)G\__](BT0D
M*&1(*P0E*`````^%H@```$B#Q#A$B>!=05S#Z"7\__](B06&IP``2(G'2(7`
M='GH@?S__TR+)<JF``!!BSPDZ'']___&@.D)````Z9_^__](BSU6IP``Z'G[
M__]!B<3I8/___TB+/4JG``!(A?]T"NBP*0``Z7'___](C3T\1P``2(GNZ%P7
M``!(B04EIP``2(G'2(7`#X1/____Z]*^!````.GJ_O__OP$```#HT_K__^BN
M_/__9BX/'X0```````\?0`#S#Q[Z,>U)B=%>2(GB2(/D\%!413'`,<E(C3VA
M_?___Q5SI@``]&8N#Q^$``````!(C3V)I@``2(T%@J8``$@Y^'052(L%%J8`
M`$B%P'0)_^`/'X``````PP\?@`````!(C3U9I@``2(TU4J8``$@I_DB)\$C!
M[C](P?@#2`'&2-'^=!1(BP7=I0``2(7`=`C_X&8/'T0``,,/'X``````\P\>
M^H`]%:8```!U*U5(@SVZI0```$B)Y70,2(L]YJ4``.AY^?__Z&3____&!>VE
M```!7<,/'P###Q^``````/,/'OKI=____P\?@`````!!5TB)_DR-3SA!5D%5
M05154TB![)@"``!D2(L$)2@```!(B80DB`(``#'`2(GB3(V4)(````!)B=`/
M'X``````08L!28LY28/`$$F#P0@/R(G`2(GY28E`\$B)^$C!Z2!(P>@H2,'O
M."4`_P``2`GX2(G/2,'A"$C!YQB!X0``_P")_T@)^$@)R$F)0/A-.=!UKDB-
MN@`"```/'X``````2(M":$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@
M_TB)0GA(.?IUU4R+#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(
MP>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH
M2,'H`DC!XAY)B?I("<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)
MT4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"
MB<%((?I,,<),`=)-B>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-
MA"B9>8):2`GZ38G52#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@
M00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(
M,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)
MTDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!
MZ`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)
MP>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'0
M2<'M&XG12"'X3#'`3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%
MB=)/C80HF7F"6D@)^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,
MBVPD2$$!T$R)XDG![`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G4
M3"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY
M@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,
MB<))P>@"2,'B'HG_3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@
M28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)
MY4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(
MP>(>18G23XV$*)EY@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%
M30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M
M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-
MO"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD
M@`````''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@A
MRDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-
ME"*9>8):38GL2#'02<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````
M00'"2(GX2,'@'DC![P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@Q
MRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````
M3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G1
M2<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ
M2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,
M">))B<R)R4@#C"2P````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)
MP(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL
M.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)
MB<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!
MZ`)(P>(>18GB3`G"28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'K
MV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)
MTD@#E"30````2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',
M3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(
MB?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQ
MT$@#C"3@````13'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX
M2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,
MB<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P
M````23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H
M`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(
M`XPD^````$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``
M2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!
MX1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"A
MZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%
MB>!("?A(B=>)TD@#E"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A
M!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B
M3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),
M"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)
M^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$
M2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)
MP$TQXHG/2`.$)#@!``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'2
M3(G"2<'H`DC!XAY%B=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9
M;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A
M^DTAUDD)UDB+E"1``0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,
MB=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&
M30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)
MP4&)R$D)SDTAYDPAPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!
MYP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D
M6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!
MX1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)
MT$G!X`5)P>X;30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPA
MT4P)\4R+M"1H`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,
MB=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U
M38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)
MUD&)T$TAUDPAX4P)\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,
M"?=)B=8!STR)X4G![`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$`
M`$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),
M">I("=%)B=9!B=5((?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G!
M[AM)P>`%30GP28G600'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)
M\DR+M"20`0``20'&30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"
M2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF
M3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)
MSDTAYDPAPDP)\DR+M"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!
MUTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!
MQDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),
M">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)
MP>`%30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+
MM"2X`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"
M2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J
M38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTA
MT$PAX4P)P4R+A"3(`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y
M3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!
MT4V)PD@#A"38`0``2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>
M08G23`GI2`G/28G-08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G5
M2,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+
ME"3@`0``2`'"3`'B38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)
MP>H"20''30GB38G$B=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)
MS$G![AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!
MQDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"
M2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A
M!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,
M`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)
MP>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ
M2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-
M,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)
MP>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA
M2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),
M`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>
M2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G2
M2<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,
M`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"
M2,'B'D6)QDP)TDR+E"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A
M!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,
M`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"
M2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ
M2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))
M`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)
MP>T"2,'B'D6)X$P)ZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!
M2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),
M`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!
MT4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$
M1#'G38G42`'73(G22<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&
M2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!
MX4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':
M3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B480
M2(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^B`Y?__05=!
M5D%505154TB#[`A(A?\/A+$```!(BP4*CP``3(LH387M#X2>````#[8'28G_
M2(GUA,!T!#P]=55%,?9-BV4`387D="]-8_9,B>L/'P!,B?),B?Y,B>?H<N/_
M_X7`=0=#@#PT/71'3(MC"$B#PPA-A>1UVDB#Q`A,B>!;74%<05U!7D%?PP\?
MA```````28G^00^V1@%)@\8!A,!T!#P]=>]%*?[KE0\?@`````!,*>M/C60T
M`4C!^P.)70#KM0\?@`````!%,>3KJ0\?`%5(B?U(@>R@````9$B+!"4H````
M2(F$))@````QP$B)YNBZY/__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*``
M`'4>O@(```!(B>_H#^7__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4
M)2@```!U"4B!Q*````!=P^@MY/__9F8N#Q^$``````!FD$%6055!5%532('L
MH````&1(BP0E*````$B)A"28````,<!(A?]T"(`_`$B)_74Q2(N$))@```!D
M2"L$)2@````/A2$!``!(@<2@````6UU!7$%=05[#9BX/'X0``````.C;XO__
M3(TMN"T``$F)Q$B%P'2[3(GGZ*3D__](A<`/A*,```"`>!,N2(U8$W4)@'L!
M`'3?#Q\`@'@3+@^$G@```$B)[^AVXO__2(G?28G&Z&OB__]!C7P&`DAC_^B^
MX?__28G928GH3(GI28G&2(G'O@$````QP$C'PO_____HW./__TR)]TB)YNA!
MXO__3(GW@_C_=!"+1"08)0#P```]`$```'19Z*3A__],B??H_.'__TR)Y^@$
MY/__2(7`#X5@____#Q\`3(GGZ(#C__](B>_HB.'__^GR_O__#Q\`@'L!+@^%
M6/___X![`@`/A"#____I2?___P\?@`````#HF_[__^NEZ+3B__\/'T``\P\>
M^E-(BQU$C```BSOH[>+__XL[Z.;B__](BQ5GC```2(T-Z&H``$B--8LL``!(
MB<?H2>/__XL[Z,+B__],C04<+@``13')6TB-%6`<``!(B<=,B<%(C35Y+```
MZ8[A__]F9BX/'X0```````\?`$%6055!5%5(@>P`$```2(,,)`!(@^P8NO\/
M``!D2(L$)2@```!(B80D"!```#'`28GE2(G]28GT2(T]/"P``$R)[NB)X?__
MA<!^58U0_TQC\D*`/#0`#X6$````A=)T0$R)\KXO````3(GOZ-#?__](A<!T
M*TB+!62+``"+..@-XO__3(GQ3(GJ2(GN2(G'Z"SA___K)F8N#Q^$``````!(
MBP4YBP``BSCHXN'__TR)XDB)[DB)Q^@TX/__2(N$)`@0``!D2"L$)2@```!U
M&4B!Q!@0``!=05Q!74%>PV:03&/PZ7C____H4^'__P\?`$%7059!54%454B)
M]5-(B?M(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GOZ!G@__](
MC70D%$B)WTF)Q#'`Z(?[__](A<`/A`8!``!(B<=)B<7H\]___TDYQ`^&T@``
M`$AC3"043(LUAHH``$R-/,T`````#[8#A,`/A*,!```\/0^$FP$``$B)V`^V
M4`%(@\`!A-)T!8#Z/77O2"G82)A-BRY*C7P@`NC]WO__30']28E%`$B%P'12
M28L&2(U+`4J+%#@/M@.(`H3`="(\/74-ZQP/'X``````A,!T$0^V`4B#P@%(
M@\$!B`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"089$@K
M!"4H````#X47`0``2(/$*%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!
MB%0%`$B#P`&$TG7NZ[T/'T``3(LUF8D``$V+!DF#.``/A,,```!,B<!%,>UF
M#Q]$``!(@\`(1(GJ08/%`4B#.`!U[XUR`TAC]DC!Y@.+!?>)``"%P'5C2(GW
M3(E$)`C'!>&)```!````Z/S=__](B<=(A<`/A%'___])8\U(BW0D"$R-/,T`
M````3(GZZ!C?__])B09(B<=!C44!1(EL)!1(F$C'!,<`````Z83^__]F+@\?
MA```````3(G'Z`C@__])B09(B<=(A<`/A/K^__])8\U,C3S-`````.NZ#Q]`
M`#'`Z7?^__^^$````$4Q[>E7____Z`_?__]F9BX/'X0```````\?0`#S#Q[Z
M2(/L"$B+!9&(``"+..@ZW___2(L5NX@``$B#Q`A(C0TX9P``2(G'2(TUV"@`
M`.F9W___9@\?A```````\P\>^D%455-(@>P`$```2(,,)`!(@>P`$```2(,,
M)`!(@^P@9$B+!"4H````2(F$)!@@```QP$B-K"00$```28GDZ#G=__],C0VX
M*```N@$0``!(B>]!B<!(C0VJ*```O@$````QP.CTWO__N@`0``!,B>9(B>_H
MU-W__T4QP(7`>"Z->`%(B<-(8__HC]S__TF)P$B%P'082&/;3(GF2(G'2(G:
MZ`;?___&!!@`28G`2(N$)!@@``!D2"L$)2@```!U#TB!Q"`@``!,B<!;74%<
MP^CHW?__#Q^$``````#S#Q[ZZ1?___\/'X``````\P\>^D%7059!54%455-(
M@>P`$```2(,,)`!(@>S(````9$B+!"4H````2(F$)+@0```QP$B)_4F)]DB-
M/><G``!(C70D'.@%^/__OB\```!(B>](B</H)=W__TB%P'1`,<!(B>Y(C3W%
M)P``Z`_\__](B>A(BY0DN!```&1(*Q0E*`````^%<@$``$B!Q,@0``!;74%<
M05U!7D%?PP\?`$B)[TR-)90G``#H(=S__TR)YDR)]T&)Q^@SW?__28G%2(7`
M=)M!C4<!08!]``!,C35L*```B40D#`^$O@```)!(A=MT$TR)[DB)W^CPW/__
MA<`/A(0```!,B>_HT-O__^L)9@\?1```Q@(`B<&#Z`%(8]!,`>J`.B]T[0-,
M)`R!^?\/```/CS7___],C;PDL````$R)\4V)Z#'`2(/L"+H`$```O@$```!,
MB?]53(T-["8``.@7W?__2(UT)#!,B?_H>MO__UI9A<!U$(M$)#@E`/```#T`
M@```=%1,B>8Q_^AJW/__28G%2(7`#X3._O__08!]```/A4/___](A=MT!8`[
M+G093(TM>"8``+D!````Z6/___\/'X0``````(![`0!TMNO?#Q^$``````"^
M`0```$R)_^BCW/__A<!UFTR)_DB-/48F``#HD/K__TR)_^BXV___Z7?^___H
MSMO__V9F+@\?A```````#Q\`\P\>^@^V!TF)^(3`=!-FD$B#QP$\+P^V!TP/
M1,>$P'7O3(G`PV9F+@\?A```````\P\>^DB%_P^$PP```%6`/P!(B?T/A)X`
M``#H<=K__TB-5`7_2#G5<A#IEP```&:02(/J`4@YU70E@#HO=/)(.=4/@WX`
M``!(@^H!2#G5=`Z`.B]T*$B#Z@%(.=5U\H!]`"]T5$B-/94E``!=Z?_:__\/
M'X``````@#HO=0E(@^H!2#G5<O)(*>HQP$B-2@)(@?D`$```=QA(@\(!N0`0
M``!(B>Y(C3U%A0``Z+#8__]=PV8/'T0``$B-/2<E``!=Z:O:__](.=5UL^N2
M#Q]``$B-/0\E``#IE-K__P\?0`#S#Q[Z05=!5D%505154TB-'0TE``!(@^Q(
M9@]O!?]B``!D2(L$)2@```!(B40D.#'`,<!(C6PD#`\I1"009@]O!>MB``!F
MB40D,`\I1"0@D#'`2(GN2(G?Z-/T__](A<!T/DB+!>^#``!(8U0D#$B+`$B-
M!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M2(T=A"0``&8/'X0``````#'`2(GN2(G?Z'/T__](A<!T/DB+!8^#``!(8U0D
M#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV
M9@\?1```2(T=+"0``&8/'X0``````#'`2(GN2(G?Z!/T__](A<!T/DB+!2^#
M``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(
MA=)U\.NV9@\?1```2(T=U2,``&8/'X0``````#'`2(GN2(G?Z+/S__](A<!T
M/DB+!<^"``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#
MP`A(B1!(A=)U\.NV9@\?1```3(TE?",``&8/'X0``````#'`2(GN3(GGZ%/S
M__](A<!T/DB+!6^"``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````
M2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=+",``&8/'X0``````#'`2(GN
M2(G?Z//R__](A<!T/DB+!0^"``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/
M'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TM@2(``&8/'X0`````
M`#'`2(GN3(GOZ)/R__](A<!T/DB+!:^!``!(8U0D#$B+`$B-!-!(BU`(2(D0
M2(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(T]>"(``&8/
M'X0``````#'`2(GN3(G_Z#/R__](A<!T/DB+!4^!``!(8U0D#$B+`$B-!-!(
MBU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TU
M(B(``&8/'X0``````#'`2(GN3(GWZ-/Q__](A<!T/DB+!>^```!(8U0D#$B+
M`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?
M1```2(T=S"$``&8/'X0``````#'`2(GN2(G?Z'/Q__](A<!T/DB+!8^```!(
M8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U
M\.NV9@\?1```2(T="B$``&8/'X0``````#'`2(GN2(G?Z!/Q__](A<!T/DB+
M!2^```!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```2(GN2(T]$R$``.C!\/__2(G&2(7`=`I,B?<QP.C?
M]/__2(GN2(T]`R$``#'`Z)[P__](B<9(A<!T#DB-/?\@```QP.BX]/__2(GN
M2(T]^2```#'`Z'?P__](B<9(A<!T.DR)[S'`Z)7T__\QP$B--0,A``!,B>?H
MA/3__TB+1"0X9$@K!"4H````=55(@\1(6UU!7$%=05Y!7\-(B>Y(C3VV(```
M,<#H)/#__TB)QDB%P'0,3(G_,<#H0O3__^NK2+A005)?0TQ%04@Y1"0A=9IF
M@7PD*4X]=9%(C70D*^O3Z&K5__]F+@\?A```````\P\>^DB#[!AD2(L$)2@`
M``!(B40D"(L%5'\``(/X_W0?2(M4)`AD2"L4)2@```!U1DB#Q!C#9BX/'X0`
M`````$B-="0$2(T]PQ\``#'`Z(WO__](B<(QP$B%TG02#[8"/#`/E<*$P`^5
MP`^VP"'0B07[?@``ZZKHY-3__P\?0`#S#Q[Z2(/L".@3U?__B<?HG-/__TB%
MP'0#2(L`2(/$",-F9BX/'X0```````\?0`#S#Q[Z055!5$R-)<H?``!52(G]
M3(GG4TB#[!AD2(L$)2@```!(B40D"#'`2(UT)`3H^^[__TB%P'0(@#@`2(G#
M=2Y(BT0D"&1(*P0E*`````^%L````$B)[DB#Q!A,B><QP%M=05Q!7>GS\O__
M#Q\`2(GN2(G'Z*73__](A<!T($B+1"0(9$@K!"4H````=79(@\086UU!7$%=
MPP\?1```2(GOZ`C3__](B=])B<7H_=+__TF-?`4"Z%/2__](@^P(28GHO@$`
M``!32,?"_____TB)QTF)Q4R-#4`>``!(C0T\'P``,<#H9-3__UA:2(M$)`AD
M2"L$)2@```!U"$R)[NE3____Z*73__\/'T0``/,/'OI(@^P(OX````#H[M'_
M_[J)J\WON?[<NIB^\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'
M0"@`````2,=`,`````#'0'@`````2(/$",,/'X0``````/,/'OI!5$F)_%53
M2(/L$&1(BP0E*````$B)1"0(,<#HC/?__P^V$$B)Q832=!1FD$B#P`&`^B\/
MMA!(#T3HA-)U[HL%"'T``$V%Y`^5PX/X_W1MA<`/E<`APX3;=2)(BT0D"&1(
M*P0E*`````^%CP```$B#Q!!;74%<PP\?1```08`\)`!TU[H$````2(TUYAT`
M`$B)[^CUT/__A<!UOTB+1"0(9$@K!"4H````=5)(@\003(GG6UU!7.EA[O__
MD#'`2(UT)`1(C3TA'0``Z.WL__](A<!T"P^V`(3`=`0\,'4/QP5C?```````
M`.EL____QP54?````0```.E9____Z#K2__]F+@\?A```````\P\>^D%72&/"
M059)B<9!54%428G\54B-;SA32(GS2(/L"$B+=RA(BU<PC0S&2#GQ2(E/*$B#
MT@!(P>@=2`'02(E',$AC1WB%P`^%Z0```$&#_C\/CB<!``!!@^Y`18GW0<'O
M!D6-;P%)P>4&20'=D/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5
M(/,/;UOP#Q%=,.CAU?__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(
M@^'X28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+
M=!4`2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`
M=.%!#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;U`````2(U\!0!(
MB=Y!*<5%.?5%#T_N36/]3(GZZ,71__]!BT0D>$0!Z$&)1"1X@_A`=9),B>=%
M*>Y,`?OH!=7__^G/_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6___
M_Y#S#Q[Z059,C78X055!5%5(B?532(M&*$B)^T2+9BA$BVXP2,'H`X/@/T$/
MS$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/CA`!``"^0````"G.=`\QTHG1@\(!
MQ@0(`#GR<O-(B>_H>-3__V8/[\`/$44X2<=&,`````!!#Q%&$$$/$48@1(EM
M<$B)[T2)973H3M3__TB+10!(B>](P>@8B`-(BT4`2,'H$(A#`4B+10"(8P)(
MBT4`B$,#2(M%"$C!Z!B(0P1(BT4(2,'H$(A#!4B+10B(8P9(BT4(B$,'2(M%
M$$C!Z!B(0PA(BT402,'H$(A#"4B+11"(8PI(BT40B$,+2(M%&$C!Z!B(0PQ(
MBT482,'H$(A##4B+11B(8PY(BT48B$,/2(M%($C!Z!B(0Q!(BT4@2,'H$(A#
M$4B+12"(8Q)(BT4@B$,36UU!7$%=05[I*\[__P\?`+HX````,?\IRH/Z"')*
MB=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"\?[__X/B
M^#'`B<:#P`A(B3PQ.=!R\^G:_O__#Q^$``````#VP@1U(X72#X3%_O__Q@``
M]L("#X2Y_O__,<EFB4P0_NFM_O__#Q\`QP``````QT00_`````#IE_[__P\?
M1```\P\>^D%7059!54%455-,C9PD`(#__TB![``0``!(@PPD`$PYW'7O2('L
M:`$``$R--<,8``!(B7PD"$B-;"0L3(GW2(GN9$B+!"4H````2(F$)%B!``!(
MC063&0``2,=$)&``````2,>$))@`````````2,=$)$``````2(E$)%!(C05O
M&```2(E$)%A(C07V&```2(E$)'A(C056&0``2(F$)(````!(C07X&```2(F$
M)(@```!(C05`&0``2(F$))````!(C048&0``2(E$)#!(C04I&0``2(E$)#@Q
MP.@\Z/__2(7`=`R`.`!)B<0/A;L$``#HYLW__XG'Z&_,__](A<`/A/X#``!,
MBRA-A>T/A/(#``!,B>_H@LS__TB-?``!Z-C+__]%#[9%`$F)Q$6$P'0Z38GG
M2(T=RQ@``)!%#[;`3(G_2(G9O@$```!(Q\+_____,<!)@\4!28/'`NC;S?__
M10^V10!%A,!UT4B-7"1P2(T]%1@``.L4#Q\`2(M["$B#PPA(A?\/A$<!``!(
MB>XQP.B%Y___28G%2(7`=-V`.`!TV$B)Q^A`Z/__A<!TS$R)[^C$S/__28G`
M2(7`#X00`0``#Q^$``````!,B<=,B40D$.C#R___3(GG2(G#Z+C+__]$C;P#
M!`0``$UC_TR)_^@%R___051,C0T,%P``2(T-!!@``$F)Q4B-!<07``!(Q\+_
M____O@$```!03(M$)"!,B>\QP.@/S?__3(GOOL`!``#H<LW__U]!6(/X_W42
MZ"7,__]$BPA!@_D1#X4D`P``2(V$)*````!,B>](B<9(B40D$.A@S/__B<.%
MP`^$Q@```$B+1"0(38GHO@$```!%,>1(C14G&```2(L(2(L%[74``$B+.#'`
MZ`O*__](BX0D6($``&1(*P0E*`````^%T04``$B!Q&B!``!,B>!;74%<05U!
M7D%?PP\?@`````!,C2T1%P``,=OK&0\?1```2&/#3(MLQ%!-A>UT.T&`?0``
M=#1,B>^#PP'HZ>;__X7`=-U,B>_H;<O__TF)P$B%P`^%L?[__TACPTR+;,10
M387M=<D/'T``13'`Z9C^__\/'X0``````(N$)+@````E`/```#T`0```#X4C
M____1(ND)+P```#H?,O__T$YQ`^%#?___XN$)+@````E_P$``#W``0``#X7V
M_O__3(G_Z'3)__](C3U!%@``2(GN28G$,<#H@.7__TB)QTB%P`^$1`(``.C/
MRO__2(G&2(M$)`A(BSCH#^W__TF)QTB%P`^$(P(``$R)_^C+R?__2(G"@_@#
M?D-(F$B--3(6``!(B50D&$F-?`?\Z+O*__^%P'4G2(M4)!B#^@0/A,\#``"-
M0OM(F$&`/`<O#X2_`P``9@\?A```````BP6*=```@_C_#X1A`P``2(T]&14`
M`(7`#X3)`0``2(TU@A4``#'`2(TM`Q8``.C]Z/__3(T]Y14``.@!R?__54C'
MPO____]-B>A03(T-GA0``+X!````3(GG2(T-L!4``#'`Z+C*__]86NM$#Q]`
M`.C;R?__@S@1=4CHP<C__X/#`4B#[`A-B>A53(T-7Q0``$R)^;X!````4TC'
MPO____],B>=0,<#H=,K__TB#Q""^P`$``$R)Y^C3RO__@_C_=*Y,B>_HILC_
M_TR)]TR)YC'`Z%GH__],B>?H\?3__^FA_?__#Q]``#';2(T]TQ0``.L2#Q]$
M``!(8\-(BWS$,$B%_W0X2(GN,<"#PP'H[N/__TB%P'3A@#@`=-Q(B<?H/,G_
M_TF)Q4B%P`^%QOO__TACPTB+?,0P2(7_=<B_#0```$R-+8`4``#HDL?__T&X
M4P```$F)Q.FY^___2(M$)`A-B>B^`0```$4QY$B-%>44``!(BPA(BP7K<@``
M2(LX,<#H"<?__^GY_/__#Q]``$B)Q^@X]/__2(N$)%B!``!D2"L$)2@````/
MA;X"``!(@<1H@0``3(GG6UU!7$%=05Y!7^F8R/__#Q^$``````!(BT0D"$R+
M..G0_?__QP6I<@```````$R)_S'V,<#H[<?__TB-/343``")Q87`#X0:_O__
MN@(```!(Q\;N____B<?HZ<C__TB-G"10`0``N@8```")[TB)WNB2QO__@+PD
M4`$```!U#H"\)%$!``!##X2_`0``,=(Q]HGOZ*_(__^_@````.B%QO__2,<`
M`2-%9TF)Q[B)J\WO28E'"$@MB\X25TF)1Q!(!?($&"M)QT<8=E0R$$F)1R!)
MQT<H`````$G'1S``````0<='>`````#K#P\?0`!(B=Y,B?_HG?7__[H`@```
M2(G>B>_H_L7__XG"A<!_X(GO2(VL)#`!``!(C1T1$P``Z(+%__],B?Y(B>_H
M!_?__TB-A"3(````3(M\)!!(B40D"`\?1```1`^V10!,B?](B=F^`0```$C'
MPO____\QP$B#Q0%)@\<"Z/K'__],.7PD"'732(T%_1(``,:$),@`````4/]T
M)!A(C0VZ$@``38GH3(GG,<"^`0```$R-#901``!(Q\+_____Z+C'__]97NE3
M_?__D$B-/;@1```QP$B)[DB)?"0(Z'KA__](A<`/A$[^__\/M@"$P`^$0_[_
M_SPP#X0[_O__QP7D<````0```$B+?"0(Z6C\__](BT0D"$B+4`A(A=(/A#C\
M__](B==(B50D".BKQ?__2(/X`P^&(?S__TB+5"0(2(TU$A(``$B-?`+\Z)O&
M__](BU0D"(7`3`]$^NG[^___@+PD4@$``$$/A3/^__^`O"13`0``0P^%)?[_
M_X"\)%0!``!(#X47_O__@+PD50$``$4/A0G^__^Z`@```$C'QL;___^)[^BP
MQO__NBD```!(B=Z)[^AAQ/__2(T%RQ$``%!3Z=3^___H#L;__V9F+@\?A```
M````#Q\`\P\>^D%505154TB#[!A(BQV+;P``9$B+!"4H````2(E$)`@QP(L[
MZ"3&__^+.TB)Q>@:QO__#[:5N````$B-;"0$2(T]2A```$B)[HB0N0```#'`
MZ"?@__](A<!T"8`X,0^$F0$``#'`Z.+J__^+.^C;Q?__N0,```"Z`0```$B-
M-2H1``!(B<?H\L/__TF)Q$B%P'0T2(M`$(L[3(LHZ*S%__](C14'$0``2(G'
M3(GNZ/K#__])BT0D$$R+($'V1"0.0`^%=@$``(L[Z'_%__^Y`P```+H!````
M2(TUU1```$B)Q^B6P___28G$2(7`=#I(C3UH#P``2(GN,<#H?=___XL[28G%
M2(7`#X3_````28M$)!!,BR#H,L7__TR)ZDB)QTR)YNB$P___BSOH'<7__[H!
M````2(TU>A```$B)Q^AYPO__BSM)B<3H_\3__TR)YDB-%7,0``!(B<?H3</_
M_XL[Z.;$__](B>Y(C3WD#@``QH"Y`````#'`Z/[>__](B07';@``28G$2(7`
M=#^^P`$``$R)Y^ARQ?__C5`!@_H!=@F#^!$/A:@```!(BT0D"&1(*P0E*```
M``^%L0```$B#Q!A;74%<05W#9I!(BSV!;@``Z(3U__](B05M;@``28G$2(7`
M=:9(C3U^$```,<#H9\3__P\?@`````"`>`$`#X1D_O__Z5C^__^02(L%06X`
M`$R+*$F+1"003(L@Z"G$__],B>Y,B>?HCN'__^GU_O__9@\?A```````BSOH
M"<3__TR)YDB)Q^B>P___Z7/^__^)P4B+!?AM``!,B>)(C3TN$```2(LP,<#H
M[,/__^B'P___#Q^``````/,/'OI(BPU];0``Z:#!___S#Q[Z2(/L"$B#Q`C#
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!P87(M`"UE`"TM`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``
M55-%4DY!344`)3`R>``E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!
M4CHZ4&%C:V5R.CI615)324].`#$N,#4R```````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2![
M"B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C
M:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@
M96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H
M:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L
M(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H
M*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I
M('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S
M92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A
M<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*
M;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D
M:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@`1L#._0````=````D''__R@!```0=?__4`$``"!U__]H`0``D'C__W@%
M``#0>O__$`$``,![__^``0``\)'__]`!``#`DO__'`(``%"3__]``@``P)3_
M_X0"```PE?__H`(``""6___@`@``<)C__RP#``"PF/__1`,``)"9__^``P``
MH)G__Y0#``"PF___^`,``.";__\,!```P)S__SP$```0HO__C`0``)"B__^H
M!```P*+__\`$``#0H___'`4``#"D__\T!0``0*7__Z0%``#@IO__\`4``-"H
M__\P!@``<+'__PP'``#PL___2`<````````4``````````%Z4@`!>!`!&PP'
M")`!```4````'````+AY__\F`````$0'$``````D````-````&!P__^``P``
M``X01@X82@\+=PB``#\:.BHS)"(`````%````%P```"X<___$```````````
M````%````'0```"P<___<`,`````````````3````(P````X>O__,!8```!"
M#A"/`DD.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`P@6"@XX00XP00XH
M0@X@0@X80@X00@X(00L```!(````W````!B0___-`````$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(
M20L`(````"@!``"<D/__@P````!!#A"&`DH.L`$"<0H.$$$."$$+0````$P!
M```(D?__;`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!
M#BA!#B!"#AA"#A!"#@A+"P`8````D`$``#22__]B`````$4.$(,"`D0."```
M/````*P!``"(DO__[0````!"#A".`D(.&(T#0@X@C`1!#BB&!4<.J"!)#L`@
M`K\*#BA!#B!"#AA"#A!"#@A#"T@```#L`0``.)/__T$"````0@X0CP)"#AB.
M`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q4!"@XX00XP00XH0@X@0@X80@X0
M0@X(10L4````.`(``#R5__\W`````$@.$%D."``X````4`(``&25___8````
M`$8.$(P"00X8A@-!#B"#!$<.H"!,#J!`20[`0`*G"@X@1`X800X00@X(00L0
M````C`(```B6__\)`````````&````"@`@``!);__P("````1@X0CP)"#AB.
M`T(.((T$0@XHC`5!#C"&!D$..(,'1PZX($P.@"("<0H..$$.,$$.*$(.($(.
M&$(.$$(."$0+`I\.B").#I`B6@Z((D$.@"(````0````!`,``+"7__\E````
M`````"P````8`P``S)?__]P`````3@X0A@("7@K&#@A,"WD*#@A'"T@*Q@X(
M10M+#@C&`$P```!(`P``?)C__T8%````1@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'2PZ``0/7!`H..$$.,$$.*$(.($(.&$(.$$(."$$+````&```
M`)@#``!\G?__?`````!(#B!M"@X(2PL``!0```"T`P``X)W__R$`````2`X0
M6`X(`%@```#,`P``^)W__PL!````1@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"
M0@H.*$8.($$.&$(.$$(."$@+9`H.*$$.($$.&$(.$$(."$8+80Y(20Y08PY(
M00Y`````%````"@$``"LGO__6`````!(#A`"3PX(0````$`$``#TGO__!@$`
M``!&#A",`D0.&(8#00X@@P1$#C`"9PH.($$.&$$.$$(."$8+<PH.($0.&$$.
M$$(."$8+```H````A`0``!!S__\R`@```$8.$(P"00X8A@-$#E`#A`$*#AA$
M#A!"#@A!"T@```"P!```E)___Y\!````1@X0CP)%#AB.`T4.((T$0@XHC`5$
M#C"&!D4..(,'1PY``N$*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"P`\````_`0`
M`.B@___K`0```$8.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#-@$*#BA!#B!"
M#AA"#A!"#@A("P``V````#P%``"8HO__D@@```!&#A"/`D(.&(X#0@X@C01"
M#BB,!4$.,(8&00XX@P=(#`NX@`)1#0='#J"#`@//`0ZH@P)E#K"#`ET.J(,"
M0@Z@@P("@@H..$0.,$$.*$(.($(.&$(.$$(."$@+`X@!#JB#`DL.L(,"7@ZH
M@P)!#J"#`EP.J(,"1`ZP@P)0#KB#`DL.P(,"2PZ@@P(#!@$*#CA$#C!!#BA"
M#B!"#AA"#A!"#@A-"P-M`0ZH@P)$#K"#`F@.J(,"00Z@@P("_0H.J(,"00ZP
M@P)%"P```#@````8!@``7*K__WD"````1@X0C0)"#AB,`T$.((8$00XH@P5$
M#D`#N0$*#BA!#B!!#AA"#A!"#@A#"Q````!4!@``H*S__Q``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$`J`````````"H````````!`````````.4"`````````0````````#U
M`@````````P``````````"`````````-`````````)!B````````&0``````
M``#`RP```````!L`````````"``````````:`````````,C+````````'```
M```````(`````````/7^_V\`````L`,````````%`````````&`-````````
M!@````````"0!`````````H`````````=@0````````+`````````!@`````
M````%0````````````````````,`````````T,T````````"`````````"@%
M````````%``````````'`````````!<`````````F!0````````'````````
M`!@3````````"`````````"``0````````D`````````&``````````>````
M``````@`````````^___;P`````!```(`````/[__V\`````F!(```````#_
M__]O``````$`````````\/__;P````#6$0```````/G__V\`````!```````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-#+````````
M`````````````````````#`@````````0"````````!0(````````&`@````
M````<"````````"`(````````)`@````````H"````````"P(````````,`@
M````````T"````````#@(````````/`@`````````"$````````0(0``````
M`"`A````````,"$```````!`(0```````%`A````````8"$```````!P(0``
M`````(`A````````D"$```````"@(0```````+`A````````P"$```````#0
M(0```````.`A````````\"$`````````(@```````!`B````````("(`````
M```P(@```````$`B````````4"(```````!@(@```````'`B````````@"(`
M``````"0(@```````*`B````````L"(```````#`(@```````-`B````````
MX"(```````#P(@`````````C````````$",````````@(P```````#`C````
M````0",```````!0(P```````&`C````````<",```````"`(P```````)`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````X'(```````!'
M0T,Z("A58G5N='4@,3$N,BXP+3$P=6)U;G1U,2D@,3$N,BXP```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N<&QT+F=O=``N<&QT+G-E8P`N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````8`P```````!@#````````'```````
M``````````````$````````````````````3````!P````(`````````.`,`
M```````X`P```````#`````````````````````(````````````````````
M)@````<````"`````````&@#````````:`,````````D````````````````
M````!````````````````````#D````'`````@````````",`P```````(P#
M````````(`````````````````````0```````````````````!'````]O__
M;P(`````````L`,```````"P`P```````-P`````````!@`````````(````
M````````````````40````L````"`````````)`$````````D`0```````#0
M"`````````<````!````"``````````8`````````%D````#`````@``````
M``!@#0```````&`-````````=@0```````````````````$`````````````
M``````!A````____;P(`````````UA$```````#6$0```````+P`````````
M!@`````````"``````````(`````````;@```/[__V\"`````````)@2````
M````F!(```````"```````````<````!````"````````````````````'T`
M```$`````@`````````8$P```````!@3````````@`$````````&````````
M``@`````````&`````````"'````!````$(`````````F!0```````"8%```
M`````"@%````````!@```!@````(`````````!@`````````D0````$````&
M```````````@`````````"`````````;````````````````````!```````
M`````````````(P````!````!@`````````@(````````"`@````````@`,`
M`````````````````!``````````$`````````"7`````0````8`````````
MH",```````"@(P```````!`````````````````````0`````````!``````
M````H`````$````&`````````+`C````````L",```````!P`P``````````
M````````$``````````0`````````*D````!````!@`````````@)P``````
M`"`G````````<#L``````````````````!````````````````````"O````
M`0````8`````````D&(```````"08@````````T````````````````````$
M````````````````````M0````$````"``````````!P`````````'``````
M``"0/@``````````````````$````````````````````+T````!`````@``
M``````"0K@```````)"N````````]`````````````````````0`````````
M``````````#+`````0````(`````````B*\```````"(KP```````&@&````
M```````````````(````````````````````U0````X````#`````````,#+
M````````P+L````````(````````````````````"``````````(````````
M`.$````/`````P````````#(RP```````,B[````````"```````````````
M``````@`````````"`````````#M````!@````,`````````T,L```````#0
MNP`````````"````````!P`````````(`````````!``````````FP````$`
M```#`````````-#-````````T+T````````P`@``````````````````"```
M```````(`````````/8````!`````P``````````T`````````#`````````
M(`````````````````````@```````````````````#\````"`````,`````
M````(-`````````@P````````$`0```````````````````@````````````
M`````````0$```$````P````````````````````(,`````````F````````
M`````````````0`````````!``````````$````#````````````````````
L`````$;`````````"@$```````````````````$`````````````````````
